# New in 0.12.2 (2021-08-11)

## Changes

-   Updated `OrderedDict` typing import to support all Python 3.7 versions ([#1114]).

## Breaking changes

None!

## Contributors

-   [@adamgayoso]
-   [@galenxing]
-   [@jjhong922]

[#1114]: https://github.com/YosefLab/scvi-tools/pull/1114
[@adamgayoso]: https://github.com/adamgayoso
[@galenxing]: https://github.com/galenxing
[@jjhong922]: https://github.com/jjhong922
